@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
 ** error.c:	error message related routine in skf
-** $Id: error.c,v 1.133 2012/03/17 08:22:12 seiji Exp seiji $
+** $Id: error.c,v 1.134 2013/04/07 03:34:21 seiji Exp seiji $
 **	out_area_out:	error character warning generation
 **	bogus_out:	same as above
 **
@@ -58,7 +58,7 @@
 /* ident */
 extern char	*rev;
 static const char	*cpyr = 
-"Copyright (c) S.Kaneko, 1993-2012. All rights reserved.\n";
+"Copyright (c) S.Kaneko, 1993-2013. All rights reserved.\n";
 
 /* error message text   */
 static char	*skf_int_err  = 
@@ -833,7 +833,8 @@ char	*fnam;
 int	mode;
 {
     int res;
-    SKFfflush((skfFILE *)stdout);
+
+    fflush(stdout);
     if (mode == 1) {
 	res = snprintf(skf_err_buf,255,
 		skf_gettext("skf: can't open output file %s\n"), fnam);
@@ -852,6 +853,12 @@ int	mode;
     } else if (mode == 6) {
 	res = snprintf(skf_err_buf,255,
 		skf_gettext("skf: can't rename output file %s\n"), fnam);
+    } else if (mode == 8) {
+	res = snprintf(skf_err_buf,255,
+		skf_gettext("skf: in-place/overwrite are unsupported on this plathome\n"));
+    } else if (mode == 9) {
+	res = snprintf(skf_err_buf,255,
+		skf_gettext("skf: temp-file name generation failed\n"));
     } else {
 	res = snprintf(skf_err_buf,255,
 		skf_gettext("skf: can't open input file %s\n"), fnam);
@@ -872,7 +879,7 @@ int	mode;
 void skf_readerr(geterrno)
 int	geterrno;
 {
-    SKFfflush((skfFILE *)stdout);
+    fflush(stdout);
     if (geterrno != EAGAIN) fputs(skf_err_header,skfstderr);
 			/* header		   */
 #ifndef SWIG_EXT
@@ -980,7 +987,7 @@ void test_support_charset()
 	("Supported charset: cname descriptions (* indicate extenal table)\n");
     fprintf(skfstderr,skf_err_msg);
 
-    fflush(skfstderr); SKFfflush((skfFILE *)stdout);
+    fflush(skfstderr); fflush(stdout);
     for (i=0; iso_ubytedef_table[i].ientry != NULL; i++) { 
 	fprintf(skfstderr,"# %s:\n",iso_ubytedef_table[i].desc);
 	uentry = iso_ubytedef_table[i].ientry;
@@ -1032,7 +1039,7 @@ void test_support_codeset()
 	("Supported codeset: cname description \n");
     fprintf(skfstderr,skf_err_msg);
 
-    fflush(skfstderr); SKFfflush((skfFILE *)stdout);
+    fflush(skfstderr); fflush(stdout);
     for (i=0; !is_code_invalid(i_codeset[i].encode); i++) { 
 	skf_cname = i_codeset[i].cname;
 	if (skf_cname == NULL) skf_cname = " -   ";
