@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
     in_converter.c	input-side converter
-    $Id: in_converter.c,v 1.169 2012/03/17 08:22:12 seiji Exp seiji $
+    $Id: in_converter.c,v 1.170 2013/04/07 03:34:21 seiji Exp seiji $
 */
 
 #include <stdio.h>
@@ -545,13 +545,13 @@ skfFILE *f;			/* can process sjis, big5 etc.	   */
     register int    c1, c2 = 0;
     skf_ucode   k0;		/* utf32 result			   */
     int	   c3,c2s;
+#ifndef PART_INDEX
     int	   d2,d3;		/* GB 18030 2nd and 3rd char.	   */
+#endif
     int	   low_hz = 0;
     int	   low_hz_ss = 0;
     unsigned long  encode;
     unsigned short *kana_table = NULL;
-    int		kana_table_limit = 0;
-    unsigned long kana_kana = 0;
 #ifdef	SUPPORT_HOOKED_BS
     int	   hooked_bs = 0;
 #endif
@@ -570,12 +570,12 @@ skfFILE *f;			/* can process sjis, big5 etc.	   */
     encode = i_codeset[in_codeset].encode;
     set_force_disp_warn;
     set_up_block;		/* guarding			   */
+#ifndef PART_INDEX
     d2 = 0; d3 = 0;
+#endif
 
     if ((gx_table_mod != NULL) && (gx_table_mod->char_width <= 2)) {
 	kana_table = gx_table_mod -> unitbl;
-	kana_table_limit = gx_table_mod -> char_width - 1;
-	kana_kana = cod_kana_mask(gx_table_mod -> is_kana);
     };
 
     reset_force_disp_warn;
@@ -1244,6 +1244,13 @@ int	cod;
 int u_in(f)			/* ucs2 input			   */
 skfFILE *f;
 {
+    if ((in_codeset == codeset_utf16be)
+    	|| (in_codeset == codeset_utf16benb)
+    	|| (in_codeset == codeset_utf32be)
+    	|| (in_codeset == codeset_utf32benb)) {
+	set_in_endian;
+    } else;
+
     if (is_encode_incomp_ucs2) {
     	/* utf-16 doesn't support any encodings			   */
 #ifdef NKF_COMPATMODE
@@ -1691,9 +1698,7 @@ static int ms213_in_calc_index(c1,c2)
 int c1,c2;
 {
     int c3;
-    int c2s;
 
-    c2s = c2;
     c3 = c2;
 
     if ((c1 <= 0xfc) && (c1 >= 0x40) && (c1 != 0x7f)) {
