@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
 ** oconv.c:	unic*de post-handler. called from in_converter.
-** $Id: oconv.c,v 1.139 2012/03/17 08:22:12 seiji Exp seiji $
+** $Id: oconv.c,v 1.140 2013/04/07 03:34:21 seiji Exp seiji $
 **
 **********************************************************************
 ** Notice for limitation of these converter programming.
@@ -1000,7 +1000,7 @@ skf_ucode ch;
 	    post_oconv(sgbuf);
 	    sgbuf = sOCD;
 	};
-	SKFfflush((skfFILE *)stdout);
+	SKFfflush((skfoFILE *)stdout);
     };
     return;
 }
