@@ -1278,7 +1278,7 @@ sensed if it fits in ISO-2022 codeset-call sequence.
 	      } else if (Qempty && (c1 == 0xff) && (c2 == 0xfe)
 			  && is_lang_unicode) {
 		  set_rescase(131);
-		  in_codeset = codeset_utf16le;
+		  in_codeset = codeset_utf16be;
 		  has_bom = TRUE;
 		  if (!(endian_protect)) set_in_big_endian ;
 		  enque(rc1); break;
@@ -1286,9 +1286,13 @@ sensed if it fits in ISO-2022 codeset-call sequence.
 			  (((c1 == 0xff) && (c2 == 0xfe)) 
 			      || ((c1 == 0xfe) && (c2 == 0xff)))) {
 			      /* c1 must be fragment of code.	   */
-		  if (c2 == 0xfe) set_in_big_endian ;
-		  else set_in_ltl_endian ;
-		  in_codeset = codeset_utf16le;
+		  if (c2 == 0xfe) {
+		  	set_in_big_endian ;
+			in_codeset = codeset_utf16be;
+		  } else {
+		  	set_in_ltl_endian ;
+			in_codeset = codeset_utf16le;
+		  };
 		  set_rescase(132); 
 		  enque(rc1); break;
 	      } else {		/* just not BOM			   */
