@@ -1,5 +1,5 @@
-#ident "$Id: skf.c,v 1.256 2012/03/17 08:22:12 seiji Exp seiji $"
-const char *rev = "SKF version 1.99.1 2013-01-14\n";
+#ident "$Id: skf.c,v 1.257 2013/04/07 03:34:21 seiji Exp seiji $"
+const char *rev = "SKF version 1.99.4 2013-04-17\n";
 /* *******************************************************************
 ** Copyright (c) 1993-2012 Seiji Kaneko. All rights reserved.
 ** Everyone is permitted to use this program in source and binary
@@ -95,6 +95,7 @@ const char *rev = "SKF version 1.99.1 2013-01-14\n";
 
 #include <utime.h>
 #include <fcntl.h>
+#include <errno.h>
 
 #include "skf.h"
 #include "skf_fileio.h"
@@ -108,7 +109,7 @@ const char *rev = "SKF version 1.99.1 2013-01-14\n";
 /* ------------------------------------------------------------- */
 /* where everything will go.					 */
 /* ------------------------------------------------------------- */
-skfFILE  *fout;
+skfoFILE  *fout;
 #endif
 
 /* options */
@@ -233,7 +234,7 @@ static char *outmode = "w";
 #endif /* NEED_BINMODE */
 #endif /* SWIG_EXT */
 
-static void	skf_gangfinish P_((skfFILE *));
+static void	skf_gangfinish P_((skfoFILE *));
 
 /* -------------------------------------------------------------- */
 /* extended option parser					  */
@@ -719,6 +720,7 @@ const struct long_option codeset_option_code[] = {
     {"ansi-x3.4",	codeset_ascii},	
     {"iso646-us",	codeset_ascii},	
     {"roman8",		codeset_ascii},	
+    {"iso2022-jp-ms",	codeset_jisms},
     {"iso2022-jp-1",	codeset_x0208},
     {"iso2022-jp-2004", codeset_x213a}, /* X-0213(2004)	   */
     {"iso2022-jp-2003", codeset_x213a}, /* X-0213(2004)	   */
@@ -1021,6 +1023,7 @@ int main(argc, argv)
     fin = skf_file_buf;		/* allocate fin pointer area	   */
     in_file_name = (char *) calloc(IN_FILE_NAME,sizeof(char));
     inb_file_name = (char *) calloc(IN_FILE_NAME,sizeof(char));
+    outs_file_name = (char *) calloc(SUFFIX_LIMIT,sizeof(char));
     if ((in_file_name == NULL) || (inb_file_name == NULL)) {
 	skferr(SKF_MALLOCERR,(long)0,(long)0); 
 	skf_exit(EXIT_FAILURE);
@@ -1046,7 +1049,7 @@ int main(argc, argv)
 #endif
 #ifdef HAVE_GETENV		/* environment argument eval.      */
 #ifdef NO_GETEUID
-#ifndef HAVE_GETUID
+#ifdef HAVE_GETUID
     if (getuid() != 0) {
 	if ((c_arg = getenv("SKFENV"))!= NULL) argeval(2,&c_arg,OPTSTR_LIMIT);
 	if ((c_arg = getenv("skfenv"))!= NULL) argeval(2,&c_arg,OPTSTR_LIMIT);
@@ -1135,7 +1138,7 @@ int main(argc, argv)
     if ((skf_fileout == FALSE) ||
     	((c >= (argc - 1)) && (is_nkf_overwrite || is_nkf_in_place))) {
 	/* not -O or overwrites with no file name given */
-	fout = (skfFILE *)stdout;
+	fout = (skfoFILE *)stdout;
 /* --- input/output initialization --- */
 	skf_ioinit(fout);
 #ifdef NKF_COMPATMODE
@@ -1148,7 +1151,7 @@ int main(argc, argv)
 	    ofilename = default_outname;
 	};
 /*@-dependenttrans@*/
-	if ((fout = (skfFILE *)fopen(ofilename,outmode)) == NULL) {
+	if ((fout = (skfoFILE *)fopen(ofilename,outmode)) == NULL) {
 	    skf_openerr(ofilename,1);
 	    skf_exit(EXIT_FAILURE);
 	};
@@ -1157,9 +1160,14 @@ int main(argc, argv)
 	skf_ioinit(fout);
 #endif
     } else {	/* nkf_overwrite or nkf_in_place		   */
+#if defined(__MINGW32__)
+	out_file_name = (char *) calloc(IN_FILE_NAME+MAX_PATH+20,
+					sizeof(char));
+	/* 20=filename("skfuuuu.tmp"=11) + Margin(8) + "\0"(1) */
+#else
 	out_file_name = (char *) calloc(IN_FILE_NAME+SUFFIX_LIMIT,
 					sizeof(char));
-	outs_file_name = (char *) calloc(SUFFIX_LIMIT,sizeof(char));
+#endif
 	outb_file_name = (char *) calloc(OUT_FILE_NAME,sizeof(char));
 	if ((out_file_name == NULL) || (outs_file_name == NULL)
 		|| (outb_file_name == NULL)) {
@@ -1194,15 +1202,15 @@ int main(argc, argv)
 			skferr(SKF_MALLOCERR,(long)0,(long)0);
 			skf_exit(EXIT_FAILURE);
 		    } else;
+		    outs_file_name=".ff";
 		    snprintf(outb_file_name,OUT_FILE_NAME,
 		    	"%s%s",inb_file_name,outs_file_name);
-		    oldmode = 
-		    	umask(S_IWGRP | S_IWOTH | S_IRGRP | S_IROTH);
+		    oldmode = umask(SKF_MASK_VAL);
 		    if ((ofd = skf_mkstemp(out_file_name)) < 0) {
 			skf_openerr(out_file_name,1);
 			skf_exit(EXIT_FAILURE);
 		    } else;
-		    if ((fout = (skfFILE *)fdopen(ofd,outmode))
+		    if ((fout = (skfoFILE *)fdopen(ofd,outmode))
 		    		== NULL) {
 			skf_openerr(out_file_name,1);
 			skf_exit(EXIT_FAILURE);
@@ -1214,22 +1222,25 @@ int main(argc, argv)
 		if (is_v_debug) fprintf(stderr,"\n[EOF:%d]\n",sy);
 #endif
 		skf_fclose (fin);	/* closing file		   */
-#ifdef NKF_COMPATMODE
 /*@-usedef@*/
 		if (is_nkf_overwrite || is_nkf_in_place) {
 		    struct stat istat;	/*@out@*/
 		    struct utimbuf otime;
 
-		    skf_gangfinish((skfFILE *)fout);
+		    skf_gangfinish((skfoFILE *)fout);
+
+		    SKFfflush((skfoFILE *)fout);
+		    fclose(fout);	/* do not use skf_fclose   */
 
-		    skf_fclose(fout);
 		    if (stat(in_file_name,&istat)) {
 		    	skf_openerr(in_file_name,2);
 			skf_exit(EXIT_FAILURE);
 		    } else;
+
 		    if (chmod(out_file_name,istat.st_mode)) {
 		    	skf_openerr(in_file_name,3);
 		    } else;
+
 		    if (is_nkf_in_place) {
 		    	otime.actime = istat.st_atime;
 			otime.modtime = istat.st_mtime;
@@ -1237,19 +1248,21 @@ int main(argc, argv)
 			    skf_openerr(out_file_name,4);
 			} else;
 		    } else;
+
 		    if (unlink(inb_file_name) < 0) {
 		    	skf_openerr(inb_file_name,5);
 			skf_exit(EXIT_FAILURE);
 		    } else;
-		    if (rename(out_file_name,outb_file_name)) {
-		    	skf_openerr(in_file_name,6);
+
+		    if (rename(out_file_name,outb_file_name) < 0) {
+		    	skf_openerr(out_file_name,6);
+			fprintf(stderr," ... %s(%d)\n",outb_file_name,errno);
 			skf_exit(EXIT_FAILURE);
 		    } else;
 		    free(outb_file_name);
 		    (void)umask(oldmode);
 		} else;
 /*@+usedef@*/
-#endif
 	    };
 	    c++;
 	};
@@ -1274,15 +1287,15 @@ int main(argc, argv)
     };
 
     if (!input_inquiry && !is_nkf_overwrite && !is_nkf_in_place) {
-    	skf_gangfinish((skfFILE *)stdout);
+    	skf_gangfinish((skfoFILE *)stdout);
     } else;
 
     if (skf_fileout && (is_nkf_overwrite || is_nkf_in_place)) {
     	if (out_file_name != NULL) free(out_file_name);
-	if (outs_file_name != NULL) free(outs_file_name);
     } else;
+    if (outs_file_name != NULL) free(outs_file_name);
 
-    return (0);
+    return (skfres);
 }
 /*@+compdef@*/
 #endif	/* !SWIG_EXT */
@@ -1998,13 +2011,13 @@ int argeval(pargc,pargv,limit)
 		  case 181: reset_nkf_compat;
 			res_sup_space_conv;
 			break;
-		  case 184: set_mime_nkfmode; break;
 #else
 		  case 184:	/*FALLTHROUGH*/
 		  case 181: 	/*FALLTHROUGH*/
 		  case 180: error_extend_option(SKF_NKFINCOMPAT,cp);
 			    break;
 #endif /* NKF_COMPATMODE */
+		  case 184: set_mime_nkfmode; break;
 		  case 185: set_lineend_lf;
 			    out_code = codeset_x0208; break;
 		  case 186: 
@@ -2253,13 +2266,11 @@ const struct long_option	*opt_t;
 {
     int	rval = -1;
     int	idx = 0;
-    int	differ;
     char *option_str;
     char *cp;
 
     while ((rval < 0) && (opt_t[idx].index >= 0)) {
 	cp = cq;
-	differ = 0;
 	option_str = opt_t[idx].option;
 	if (cname_comp(cp,option_str) >= 0) {
 	    rval = opt_t[idx].index;
@@ -2281,7 +2292,7 @@ const struct long_option	*opt_t;
 
 /* --------------------------------------------------------------- */
 static void skf_gangfinish(fout)
-skfFILE *fout;
+skfoFILE *fout;
 {
     if (is_jis(conv_cap)) JIS_finish_procedure();
     else if (is_euc(conv_cap)) EUC_finish_procedure();
@@ -2296,9 +2307,9 @@ skfFILE *fout;
 /* if any characters hang in encoder, push out these stuffs. 	   */
 /* and also put eol if base64 encode.				   */
     oconv(sFLSH);  /* remains should be cleared	   */
-    SKFfflush(fout);
+    SKFfflush((skfoFILE *)fout);
     if (o_encode) encoder_tail();
-    SKFfflush(fout);
+    SKFfflush((skfoFILE *)fout);
 }
 
 /* --------------------------------------------------------------- */
